==> blesta-5.10.2.zip: blesta/language/uk_ua/app_controller.php <==
<?php
/**
 * App Controller
 *
 * @package blesta
 * @subpackage blesta.language.uk_ua
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AppController.dropzone.text'] = 'Опустіть файли сюди, щоб завантажити, або натисніть, щоб вибрати файли';
$lang['AppController.sreader.navigation'] = 'Перейдіть до навігації';
$lang['AppController.sreader.dropdown'] = 'Перемикач Випадаюче меню';
$lang['AppController.graphs.label.total'] = 'Всього';
$lang['AppController.graphs.control_label.grouped'] = 'Згруповані';
$lang['AppController.graphs.control_label.expanded'] = 'Розширений';
$lang['AppController.graphs.control_label.stream'] = 'Потік';
$lang['AppController.graphs.control_label.stacked'] = 'Складені в стопку';
$lang['AppController.dates.monthabbr_dec'] = 'Грудень';
$lang['AppController.dates.monthabbr_nov'] = 'Листопад';
$lang['AppController.dates.monthabbr_oct'] = 'Жовтень';
$lang['AppController.dates.monthabbr_sep'] = 'Sep';
$lang['AppController.dates.monthabbr_aug'] = 'Серпень';
$lang['AppController.dates.monthabbr_jul'] = 'Джул';
$lang['AppController.dates.monthabbr_jun'] = 'Джун';
$lang['AppController.dates.monthabbr_may'] = 'Травень';
$lang['AppController.dates.monthabbr_apr'] = 'Квітень';
$lang['AppController.dates.monthabbr_mar'] = 'Мар';
$lang['AppController.dates.monthabbr_feb'] = 'Лютий';
$lang['AppController.dates.monthabbr_jan'] = 'Ян';
$lang['AppController.dates.month_dec'] = 'Грудень';
$lang['AppController.dates.month_nov'] = 'Листопад';
$lang['AppController.dates.month_oct'] = 'Жовтень';
$lang['AppController.dates.month_sep'] = 'Вересень';
$lang['AppController.dates.month_aug'] = 'Серпень';
$lang['AppController.dates.month_jul'] = 'Липень';
$lang['AppController.dates.month_jun'] = 'Червень';
$lang['AppController.dates.month_may'] = 'Травень';
$lang['AppController.dates.month_apr'] = 'Квітень';
$lang['AppController.dates.month_mar'] = 'Березень';
$lang['AppController.dates.month_feb'] = 'Лютий';
$lang['AppController.dates.month_jan'] = 'Січень';
$lang['AppController.dates.dayabbr_sat'] = 'Sat';
$lang['AppController.dates.dayabbr_fri'] = 'Фрі';
$lang['AppController.dates.dayabbr_thur'] = 'Ту';
$lang['AppController.dates.dayabbr_wed'] = 'Ср.';
$lang['AppController.dates.dayabbr_tue'] = 'Туе.';
$lang['AppController.dates.dayabbr_mon'] = 'Mon';
$lang['AppController.dates.dayabbr_sun'] = 'Сонце';
$lang['AppController.dates.day_sat'] = 'Субота';
$lang['AppController.dates.day_fri'] = 'П\'ятниця';
$lang['AppController.dates.day_thu'] = 'Четвер';
$lang['AppController.dates.day_wed'] = 'Середа';
$lang['AppController.dates.day_tue'] = 'Вівторок';
$lang['AppController.dates.day_mon'] = 'Понеділок';
$lang['AppController.dates.day_sun'] = 'Неділя';
$lang['AppController.client_structure.text_managers'] = 'Менеджери';
$lang['AppController.client_structure.text_contacts'] = 'Контакти';
$lang['AppController.client_structure.text_accounts'] = 'Платіжні рахунки';
$lang['AppController.client_structure.text_emails'] = 'Історія електронної пошти';
$lang['AppController.client_structure.text_update_account'] = 'Керування обліковим записом';
$lang['AppController.client_structure.text_login'] = 'Увійдіть в систему';
$lang['AppController.client_structure.text_logout'] = 'Вийти з системи';
$lang['AppController.client_structure.text_return_to_portal'] = 'Повернутися на портал';
$lang['AppController.client_structure.default_title'] = 'Мій обліковий запис';
$lang['AppController.client_structure.staff_as_client_note'] = 'Повернутися до Порталу персоналу';
$lang['AppController.structure.text_search_placeholder'] = '%1$s...';
$lang['AppController.structure.text_maintenance'] = 'Наразі увімкнено режим обслуговування, і клієнти не можуть увійти в систему. Натисніть тут, щоб змінити.';
$lang['AppController.structure.text_logout'] = 'Вийти з системи';
$lang['AppController.structure.text_settings'] = 'Налаштування';
$lang['AppController.structure.text_myinfo'] = 'Моя інформація';
$lang['AppController.message.close'] = '×';
$lang['AppController.banners.text_switch_back'] = 'Поверніться до мого облікового запису';
$lang['AppController.banners.client_manager'] = 'Наразі ви керуєте акаунтом, який запросив вас до керування.';
$lang['AppController.tooltip.text'] = '?';
$lang['AppController.modal.text_confirm'] = 'Будь ласка, підтвердіть';
$lang['AppController.modal.text_close'] = 'Закрити';
$lang['AppController.select.please'] = '-- Будь ласка, виберіть.';
$lang['AppController.!success.license_key_updated'] = 'Ваш ліцензійний ключ успішно оновлено. Будь ласка, увійдіть в систему.';
$lang['AppController.!success.license_updated'] = 'Ваша ліцензія успішно підтверджена. Будь ласка, увійдіть в систему.';
$lang['AppController.!error.invalid_csrf'] = 'Токен форми недійсний.';
$lang['AppController.!error.unauthorized_access'] = 'Ви не маєте права доступу до цього ресурсу';
$lang['AppController.lang.dir'] = 'ltr';

==> blesta-5.11.4.zip: blesta/language/uk_ua/app_controller.php <==
<?php
/**
 * App Controller
 *
 * @package blesta
 * @subpackage blesta.language.uk_ua
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AppController.dropzone.text'] = 'Опустіть файли сюди, щоб завантажити, або натисніть, щоб вибрати файли';
$lang['AppController.sreader.navigation'] = 'Перейдіть до навігації';
$lang['AppController.sreader.dropdown'] = 'Перемикач Випадаюче меню';
$lang['AppController.graphs.label.total'] = 'Всього';
$lang['AppController.graphs.control_label.grouped'] = 'Згруповані';
$lang['AppController.graphs.control_label.expanded'] = 'Розширений';
$lang['AppController.graphs.control_label.stream'] = 'Потік';
$lang['AppController.graphs.control_label.stacked'] = 'Складені в стопку';
$lang['AppController.dates.monthabbr_dec'] = 'Грудень';
$lang['AppController.dates.monthabbr_nov'] = 'Листопад';
$lang['AppController.dates.monthabbr_oct'] = 'Жовтень';
$lang['AppController.dates.monthabbr_sep'] = 'Sep';
$lang['AppController.dates.monthabbr_aug'] = 'Серпень';
$lang['AppController.dates.monthabbr_jul'] = 'Джул';
$lang['AppController.dates.monthabbr_jun'] = 'Джун';
$lang['AppController.dates.monthabbr_may'] = 'Травень';
$lang['AppController.dates.monthabbr_apr'] = 'Квітень';
$lang['AppController.dates.monthabbr_mar'] = 'Мар';
$lang['AppController.dates.monthabbr_feb'] = 'Лютий';
$lang['AppController.dates.monthabbr_jan'] = 'Ян';
$lang['AppController.dates.month_dec'] = 'Грудень';
$lang['AppController.dates.month_nov'] = 'Листопад';
$lang['AppController.dates.month_oct'] = 'Жовтень';
$lang['AppController.dates.month_sep'] = 'Вересень';
$lang['AppController.dates.month_aug'] = 'Серпень';
$lang['AppController.dates.month_jul'] = 'Липень';
$lang['AppController.dates.month_jun'] = 'Червень';
$lang['AppController.dates.month_may'] = 'Травень';
$lang['AppController.dates.month_apr'] = 'Квітень';
$lang['AppController.dates.month_mar'] = 'Березень';
$lang['AppController.dates.month_feb'] = 'Лютий';
$lang['AppController.dates.month_jan'] = 'Січень';
$lang['AppController.dates.dayabbr_sat'] = 'Sat';
$lang['AppController.dates.dayabbr_fri'] = 'Фрі';
$lang['AppController.dates.dayabbr_thur'] = 'Ту';
$lang['AppController.dates.dayabbr_wed'] = 'Ср.';
$lang['AppController.dates.dayabbr_tue'] = 'Туе.';
$lang['AppController.dates.dayabbr_mon'] = 'Mon';
$lang['AppController.dates.dayabbr_sun'] = 'Сонце';
$lang['AppController.dates.day_sat'] = 'Субота';
$lang['AppController.dates.day_fri'] = 'П\'ятниця';
$lang['AppController.dates.day_thu'] = 'Четвер';
$lang['AppController.dates.day_wed'] = 'Середа';
$lang['AppController.dates.day_tue'] = 'Вівторок';
$lang['AppController.dates.day_mon'] = 'Понеділок';
$lang['AppController.dates.day_sun'] = 'Неділя';
$lang['AppController.client_structure.text_managers'] = 'Менеджери';
$lang['AppController.client_structure.text_contacts'] = 'Контакти';
$lang['AppController.client_structure.text_accounts'] = 'Платіжні рахунки';
$lang['AppController.client_structure.text_emails'] = 'Історія електронної пошти';
$lang['AppController.client_structure.text_update_account'] = 'Керування обліковим записом';
$lang['AppController.client_structure.text_login'] = 'Увійдіть в систему';
$lang['AppController.client_structure.text_logout'] = 'Вийти з системи';
$lang['AppController.client_structure.text_return_to_portal'] = 'Повернутися на портал';
$lang['AppController.client_structure.default_title'] = 'Мій обліковий запис';
$lang['AppController.client_structure.staff_as_client_note'] = 'Повернутися до Порталу персоналу';
$lang['AppController.structure.text_search_placeholder'] = '%1$s...';
$lang['AppController.structure.text_maintenance'] = 'Наразі увімкнено режим обслуговування, і клієнти не можуть увійти в систему. Натисніть тут, щоб змінити.';
$lang['AppController.structure.text_logout'] = 'Вийти з системи';
$lang['AppController.structure.text_settings'] = 'Налаштування';
$lang['AppController.structure.text_myinfo'] = 'Моя інформація';
$lang['AppController.message.close'] = '×';
$lang['AppController.banners.text_switch_back'] = 'Поверніться до мого облікового запису';
$lang['AppController.banners.client_manager'] = 'Наразі ви керуєте акаунтом, який запросив вас до керування.';
$lang['AppController.tooltip.text'] = '?';
$lang['AppController.modal.text_confirm'] = 'Будь ласка, підтвердіть';
$lang['AppController.modal.text_close'] = 'Закрити';
$lang['AppController.select.please'] = '-- Будь ласка, виберіть.';
$lang['AppController.!success.license_key_updated'] = 'Ваш ліцензійний ключ успішно оновлено. Будь ласка, увійдіть в систему.';
$lang['AppController.!success.license_updated'] = 'Ваша ліцензія успішно підтверджена. Будь ласка, увійдіть в систему.';
$lang['AppController.!error.invalid_csrf'] = 'Токен форми недійсний.';
$lang['AppController.!error.unauthorized_access'] = 'Ви не маєте права доступу до цього ресурсу';
$lang['AppController.lang.dir'] = 'ltr';
$lang['AppController.!error.client_unauthorized_access'] = 'Якщо у вас немає дозволу на доступ до цього ресурсу, зверніться до основного власника облікового запису, щоб отримати доступ';
